#ifndef TREEITEM_H
#define TREEITEM_H

#include <QList>
#include <QVariant>

class LinkableMapObj;

class TreeItem
{
public:
	enum Type {Undefined,MapCenter,Branch,Image};
    TreeItem(const QList<QVariant> &data, TreeItem *parent = 0);
    ~TreeItem();

	// General housekeeping
    void appendChild (TreeItem *child);
	void removeChild (int row);

    TreeItem *child(int row);
    int childCount() const;
    int columnCount() const;
	int branchCount() const;

    int row() const;
	int column() const;
	int depth() ;
    TreeItem *parent();
	int num();		// object index, e.g. branch number

	// Accessing data
    QVariant data(int column) const;
	void setHeading (const QString s);
	QString getHeading();
	void setNote(const QString s);
	QString getNote();
	void setType (const Type t);
	Type getType ();
	QString getTypeName ();

	// Navigation and selection
	TreeItem* getChildNum(const int &n);
	TreeItem* getFirstBranch();
	TreeItem* getLastBranch();
	TreeItem* getBranchNum(const int &n);
	void setLastSelectedBranch();
	TreeItem* getLastSelectedBranch();

	
	// Relation to map objects in graphicsscene
	LinkableMapObj* getLMO();
	void setLMO (LinkableMapObj*);

protected:
    QList<TreeItem*> childItems;
    QList<QVariant> itemData;
    TreeItem *parentItem;
 
	Type type;
	LinkableMapObj *lmo;

	int branchOffset;
	int branchCounter;
	int lastSelectedBranchNum;
};

#endif
